<?xml version="1.0"?>
<!--
    Turns certication XML into an indexed HTML document, with each
    section as a seperate file. Requires an XSLT processor which supports
    the document element, such as InstantSaxon.
    Copyright (C)1999, 2000, 2002 Dylan Walsh.

    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
-->
<!DOCTYPE xsl:stylesheet [<!ENTITY nbsp "&#160;">]> 
<xsl:stylesheet	xmlns:xsl="http://www.w3.org/1999/XSL/Transform" version="1.1"> 
 <xsl:import href="cert2html.xsl"/>
 <xsl:output method="html" indent="yes" />
 <xsl:strip-space elements="*"/>

 <xsl:template match="document">
  <html>
   <head>
    <title><xsl:value-of select="title"/></title>
   </head>
   <body>
    <xsl:call-template name="css" />
    <p align="center">
     <h1><xsl:value-of select="title"/></h1>
     <xsl:apply-templates select="legal" />
    </p>
    <xsl:apply-templates select="disclaimer" />
    <p>
     This guide is available in several forms:<br/>
     <a href="full.htm">To view this whole document as one long webpage, click here.</a><br/>
     <a href="printer.htm">To view a printer friendly-version, click here.</a><br/>
     <a href="javacert.zip">To download all the files related to this document, click here.</a><br/>
    </p>
    <hr />
    <xsl:apply-templates select="."  mode="contents" />
   </body>
  </html>
  <xsl:apply-templates select="section" />
 </xsl:template>

 <xsl:template match="*" mode="contents">
  <p>
   <a name="full"><h2>Contents</h2></a>
    <xsl:for-each select="section"> 
     <blockquote><a href="{generate-id(section_title)}.htm"><h3><xsl:value-of select="section_title"/></h3></a>
      <xsl:for-each select=".//objh"> 
       <blockquote><a href="{generate-id(../../section_title)}.htm#{generate-id()}"><xsl:value-of select="."/></a>
       <br/>
       <xsl:for-each select="..//*[name()='subh' or name()='big']"> 
        <blockquote><a href="{generate-id(../../section_title)}.htm#{generate-id()}"><small><xsl:value-of select="."/></small></a>
         <br/>
        </blockquote>
       </xsl:for-each>
       </blockquote>
      </xsl:for-each>
      <!-- The introduction section has 'subh's but no objectives -->
      <xsl:for-each select="*[name()='subh' or name()='big']"> 
       <blockquote>
        <blockquote><a href="{generate-id(../section_title)}.htm#{generate-id()}"><small><xsl:value-of select="."/></small></a>
         <br/>
        </blockquote>
       </blockquote>
      </xsl:for-each>
     </blockquote>
    </xsl:for-each>
  </p>
</xsl:template>
  
 <!-- Create HTML structure, in a seperate file for the section -->
 <xsl:template match="section">
  <xsl:document href="{generate-id(section_title)}.htm">
   <html>
    <head>
     <title><xsl:value-of select="/document/title"/></title>
    </head>
    <body>
     <xsl:call-template name="css" />
     <xsl:apply-templates select="." mode="navigation" />
     <p>
      <xsl:apply-templates />
     </p>
     <p align="center">
      <hr />
      <xsl:apply-templates select="." mode="navigation" />
     </p>
     <p align="center">
      <small>
       <xsl:apply-templates select="/document/legal/copyright-declaration" />
       <br/>
       <xsl:apply-templates select="/document/legal/fdl" />
      </small>
     </p>
    </body>
   </html>
  </xsl:document>
 </xsl:template>

 <!-- Links at top and bottom of each page -->
 <xsl:template match="section" mode="navigation"> 
      <xsl:if test="preceding-sibling::section">
       <a href="{generate-id(preceding-sibling::section[1]/section_title)}.htm">&lt;Previous</a>
       &nbsp;&nbsp;
      </xsl:if>
      <a href="index.htm">Back to Start</a>&nbsp;&nbsp;<a href="index.htm#full">Contents</a>&nbsp;&nbsp;
      <xsl:if test="following-sibling::section">
       <a href="{generate-id(following-sibling::section[1]/section_title)}.htm">Next></a>
      </xsl:if>
 </xsl:template>
</xsl:stylesheet>
